@@ -1893,14 +1893,14 @@ int Inf_Upd()
     y = (gm.o_my - gm.c_y) / L_SIZE;
 
     if (gm.o_mx < gm.c_x + gm.b_x || gm.o_my < gm.c_y  || x >= gm.c_l_st->l_num || y >= gm.c_l_st->c_num) {
-        sprintf(gm.inf_str, "Chapter %i, Level %i", gm.c_ch + 1, gm.c_l_id + 1);
+        sprintf(gm.inf_str, "Tier %i, Puzzle %i", gm.c_ch + 1, gm.c_l_id + 1);
         return 0;
     }
     if (!gm.c_s_inf->cmp[y * gm.c_s_inf->l_num + x] && !gm.c_s_inf->c_opn[y]) {
         sprintf(gm.inf_str, "Access Denied");
         return 0;
     }
-    sprintf(gm.inf_str, "Chapter %i, Level %i", y + 1, x + 1);
+    sprintf(gm.inf_str, "Tier %i, Puzzle %i", y + 1, x + 1);
     if (gm.bttn[1]) {
         gm.w_c = y;
         gm.w_l = x;
